"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.loadtesting.api.v1.test.test_pb2
import yandex.cloud.loadtesting.api.v1.test_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class TestServiceStub:
    """A set of methods for managing tests."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.test_service_pb2.CreateTestRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates (runs) a test in the specified folder."""

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.test_service_pb2.GetTestRequest,
        yandex.cloud.loadtesting.api.v1.test.test_pb2.Test,
    ]
    """Returns the specified test.

    To get the list of all available tests, make a [List] request.
    """

    Stop: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.test_service_pb2.StopTestRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Stops the specified test."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.test_service_pb2.DeleteTestRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes specified tests."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.test_service_pb2.ListTestsRequest,
        yandex.cloud.loadtesting.api.v1.test_service_pb2.ListTestsResponse,
    ]
    """Retrieves the list of test in the specified folder."""

class TestServiceAsyncStub:
    """A set of methods for managing tests."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.test_service_pb2.CreateTestRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates (runs) a test in the specified folder."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.test_service_pb2.GetTestRequest,
        yandex.cloud.loadtesting.api.v1.test.test_pb2.Test,
    ]
    """Returns the specified test.

    To get the list of all available tests, make a [List] request.
    """

    Stop: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.test_service_pb2.StopTestRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Stops the specified test."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.test_service_pb2.DeleteTestRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes specified tests."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.test_service_pb2.ListTestsRequest,
        yandex.cloud.loadtesting.api.v1.test_service_pb2.ListTestsResponse,
    ]
    """Retrieves the list of test in the specified folder."""

class TestServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing tests."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.loadtesting.api.v1.test_service_pb2.CreateTestRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates (runs) a test in the specified folder."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.loadtesting.api.v1.test_service_pb2.GetTestRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.loadtesting.api.v1.test.test_pb2.Test, collections.abc.Awaitable[yandex.cloud.loadtesting.api.v1.test.test_pb2.Test]]:
        """Returns the specified test.

        To get the list of all available tests, make a [List] request.
        """

    @abc.abstractmethod
    def Stop(
        self,
        request: yandex.cloud.loadtesting.api.v1.test_service_pb2.StopTestRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Stops the specified test."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.loadtesting.api.v1.test_service_pb2.DeleteTestRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes specified tests."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.loadtesting.api.v1.test_service_pb2.ListTestsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.loadtesting.api.v1.test_service_pb2.ListTestsResponse, collections.abc.Awaitable[yandex.cloud.loadtesting.api.v1.test_service_pb2.ListTestsResponse]]:
        """Retrieves the list of test in the specified folder."""

def add_TestServiceServicer_to_server(servicer: TestServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/assistants/v1/searchindex/search_index_file.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAyandex/cloud/ai/assistants/v1/searchindex/search_index_file.proto\x12)yandex.cloud.ai.assistants.v1.searchindex\x1a\x1fgoogle/protobuf/timestamp.proto\"z\n\x0fSearchIndexFile\x12\n\n\x02id\x18\x01 \x01(\t\x12\x17\n\x0fsearch_index_id\x18\x02 \x01(\t\x12\x12\n\ncreated_by\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x8a\x01\n-yandex.cloud.api.ai.assistants.v1.searchindexZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/searchindex;searchindexb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.assistants.v1.searchindex.search_index_file_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-yandex.cloud.api.ai.assistants.v1.searchindexZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/searchindex;searchindex'
  _globals['_SEARCHINDEXFILE']._serialized_start=145
  _globals['_SEARCHINDEXFILE']._serialized_end=267
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/api/v1/regression_dashboard_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.loadtesting.api.v1.regression import dashboard_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_regression_dot_dashboard__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nByandex/cloud/loadtesting/api/v1/regression_dashboard_service.proto\x12\x1fyandex.cloud.loadtesting.api.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a:yandex/cloud/loadtesting/api/v1/regression/dashboard.proto\x1a\x1dyandex/cloud/validation.proto\"\xe5\x01\n CreateRegressionDashboardRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1f\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12N\n\x07\x63ontent\x18\x04 \x01(\x0b\x32=.yandex.cloud.loadtesting.api.v1.regression.Dashboard.Content\"9\n!CreateRegressionDashboardMetadata\x12\x14\n\x0c\x64\x61shboard_id\x18\x01 \x01(\t\"I\n\x1dGetRegressionDashboardRequest\x12\"\n\x0c\x64\x61shboard_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50J\x04\x08\x02\x10\x03\"T\n DeleteRegressionDashboardRequest\x12\"\n\x0c\x64\x61shboard_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\"9\n!DeleteRegressionDashboardMetadata\x12\x14\n\x0c\x64\x61shboard_id\x18\x01 \x01(\t\"\xa2\x01\n\x1fListRegressionDashboardsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x03 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x05 \x01(\tB\n\x8a\xc8\x31\x06<=1000J\x04\x08\x02\x10\x03\"\x91\x01\n ListRegressionDashboardsResponse\x12I\n\ndashboards\x18\x01 \x03(\x0b\x32\x35.yandex.cloud.loadtesting.api.v1.regression.Dashboard\x12\"\n\x0fnext_page_token\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\x9f\x02\n UpdateRegressionDashboardRequest\x12\x1a\n\x0c\x64\x61shboard_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x04 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1f\n\x0b\x64\x65scription\x18\x05 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12N\n\x07\x63ontent\x18\x06 \x01(\x0b\x32=.yandex.cloud.loadtesting.api.v1.regression.Dashboard.Content\"9\n!UpdateRegressionDashboardMetadata\x12\x14\n\x0c\x64\x61shboard_id\x18\x01 \x01(\t2\xe1\x08\n\x1aRegressionDashboardService\x12\xe0\x01\n\x06\x43reate\x12\x41.yandex.cloud.loadtesting.api.v1.CreateRegressionDashboardRequest\x1a!.yandex.cloud.operation.Operation\"p\xb2\xd2*9\n!CreateRegressionDashboardMetadata\x12\x14regression.Dashboard\x82\xd3\xe4\x93\x02-\"(/loadtesting/api/v1/regressionDashboards:\x01*\x12\xbd\x01\n\x03Get\x12>.yandex.cloud.loadtesting.api.v1.GetRegressionDashboardRequest\x1a\x35.yandex.cloud.loadtesting.api.v1.regression.Dashboard\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/loadtesting/api/v1/regressionDashboards/{dashboard_id}\x12\xbd\x01\n\x04List\x12@.yandex.cloud.loadtesting.api.v1.ListRegressionDashboardsRequest\x1a\x41.yandex.cloud.loadtesting.api.v1.ListRegressionDashboardsResponse\"0\x82\xd3\xe4\x93\x02*\x12(/loadtesting/api/v1/regressionDashboards\x12\xed\x01\n\x06\x44\x65lete\x12\x41.yandex.cloud.loadtesting.api.v1.DeleteRegressionDashboardRequest\x1a!.yandex.cloud.operation.Operation\"}\xb2\xd2*:\n!DeleteRegressionDashboardMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x39*7/loadtesting/api/v1/regressionDashboards/{dashboard_id}\x12\xef\x01\n\x06Update\x12\x41.yandex.cloud.loadtesting.api.v1.UpdateRegressionDashboardRequest\x1a!.yandex.cloud.operation.Operation\"\x7f\xb2\xd2*9\n!UpdateRegressionDashboardMetadata\x12\x14regression.Dashboard\x82\xd3\xe4\x93\x02<27/loadtesting/api/v1/regressionDashboards/{dashboard_id}:\x01*Bv\n#yandex.cloud.api.loadtesting.api.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1;loadtestingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.regression_dashboard_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#yandex.cloud.api.loadtesting.api.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1;loadtesting'
  _CREATEREGRESSIONDASHBOARDREQUEST.fields_by_name['folder_id']._options = None
  _CREATEREGRESSIONDASHBOARDREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEREGRESSIONDASHBOARDREQUEST.fields_by_name['name']._options = None
  _CREATEREGRESSIONDASHBOARDREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _CREATEREGRESSIONDASHBOARDREQUEST.fields_by_name['description']._options = None
  _CREATEREGRESSIONDASHBOARDREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _GETREGRESSIONDASHBOARDREQUEST.fields_by_name['dashboard_id']._options = None
  _GETREGRESSIONDASHBOARDREQUEST.fields_by_name['dashboard_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEREGRESSIONDASHBOARDREQUEST.fields_by_name['dashboard_id']._options = None
  _DELETEREGRESSIONDASHBOARDREQUEST.fields_by_name['dashboard_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTREGRESSIONDASHBOARDSREQUEST.fields_by_name['folder_id']._options = None
  _LISTREGRESSIONDASHBOARDSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTREGRESSIONDASHBOARDSREQUEST.fields_by_name['page_size']._options = None
  _LISTREGRESSIONDASHBOARDSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTREGRESSIONDASHBOARDSREQUEST.fields_by_name['page_token']._options = None
  _LISTREGRESSIONDASHBOARDSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTREGRESSIONDASHBOARDSREQUEST.fields_by_name['filter']._options = None
  _LISTREGRESSIONDASHBOARDSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _LISTREGRESSIONDASHBOARDSRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTREGRESSIONDASHBOARDSRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\212\3101\005<=100'
  _UPDATEREGRESSIONDASHBOARDREQUEST.fields_by_name['dashboard_id']._options = None
  _UPDATEREGRESSIONDASHBOARDREQUEST.fields_by_name['dashboard_id']._serialized_options = b'\350\3071\001'
  _UPDATEREGRESSIONDASHBOARDREQUEST.fields_by_name['name']._options = None
  _UPDATEREGRESSIONDASHBOARDREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _UPDATEREGRESSIONDASHBOARDREQUEST.fields_by_name['description']._options = None
  _UPDATEREGRESSIONDASHBOARDREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _REGRESSIONDASHBOARDSERVICE.methods_by_name['Create']._options = None
  _REGRESSIONDASHBOARDSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*9\n!CreateRegressionDashboardMetadata\022\024regression.Dashboard\202\323\344\223\002-\"(/loadtesting/api/v1/regressionDashboards:\001*'
  _REGRESSIONDASHBOARDSERVICE.methods_by_name['Get']._options = None
  _REGRESSIONDASHBOARDSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\0029\0227/loadtesting/api/v1/regressionDashboards/{dashboard_id}'
  _REGRESSIONDASHBOARDSERVICE.methods_by_name['List']._options = None
  _REGRESSIONDASHBOARDSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002*\022(/loadtesting/api/v1/regressionDashboards'
  _REGRESSIONDASHBOARDSERVICE.methods_by_name['Delete']._options = None
  _REGRESSIONDASHBOARDSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*:\n!DeleteRegressionDashboardMetadata\022\025google.protobuf.Empty\202\323\344\223\0029*7/loadtesting/api/v1/regressionDashboards/{dashboard_id}'
  _REGRESSIONDASHBOARDSERVICE.methods_by_name['Update']._options = None
  _REGRESSIONDASHBOARDSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*9\n!UpdateRegressionDashboardMetadata\022\024regression.Dashboard\202\323\344\223\002<27/loadtesting/api/v1/regressionDashboards/{dashboard_id}:\001*'
  _globals['_CREATEREGRESSIONDASHBOARDREQUEST']._serialized_start=333
  _globals['_CREATEREGRESSIONDASHBOARDREQUEST']._serialized_end=562
  _globals['_CREATEREGRESSIONDASHBOARDMETADATA']._serialized_start=564
  _globals['_CREATEREGRESSIONDASHBOARDMETADATA']._serialized_end=621
  _globals['_GETREGRESSIONDASHBOARDREQUEST']._serialized_start=623
  _globals['_GETREGRESSIONDASHBOARDREQUEST']._serialized_end=696
  _globals['_DELETEREGRESSIONDASHBOARDREQUEST']._serialized_start=698
  _globals['_DELETEREGRESSIONDASHBOARDREQUEST']._serialized_end=782
  _globals['_DELETEREGRESSIONDASHBOARDMETADATA']._serialized_start=784
  _globals['_DELETEREGRESSIONDASHBOARDMETADATA']._serialized_end=841
  _globals['_LISTREGRESSIONDASHBOARDSREQUEST']._serialized_start=844
  _globals['_LISTREGRESSIONDASHBOARDSREQUEST']._serialized_end=1006
  _globals['_LISTREGRESSIONDASHBOARDSRESPONSE']._serialized_start=1009
  _globals['_LISTREGRESSIONDASHBOARDSRESPONSE']._serialized_end=1154
  _globals['_UPDATEREGRESSIONDASHBOARDREQUEST']._serialized_start=1157
  _globals['_UPDATEREGRESSIONDASHBOARDREQUEST']._serialized_end=1444
  _globals['_UPDATEREGRESSIONDASHBOARDMETADATA']._serialized_start=1446
  _globals['_UPDATEREGRESSIONDASHBOARDMETADATA']._serialized_end=1503
  _globals['_REGRESSIONDASHBOARDSERVICE']._serialized_start=1506
  _globals['_REGRESSIONDASHBOARDSERVICE']._serialized_end=2627
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Polygon(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERTICES_FIELD_NUMBER: builtins.int
    @property
    def vertices(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Vertex]:
        """The bounding polygon vertices."""

    def __init__(
        self,
        *,
        vertices: collections.abc.Iterable[global___Vertex] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["vertices", b"vertices"]) -> None: ...

global___Polygon = Polygon

@typing.final
class Vertex(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    X_FIELD_NUMBER: builtins.int
    Y_FIELD_NUMBER: builtins.int
    x: builtins.int
    """X coordinate in pixels."""
    y: builtins.int
    """Y coordinate in pixels."""
    def __init__(
        self,
        *,
        x: builtins.int = ...,
        y: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["x", b"x", "y", b"y"]) -> None: ...

global___Vertex = Vertex



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/speechsense/v1/classifier.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,yandex/cloud/speechsense/v1/classifier.proto\x12\x1byandex.cloud.speechsense.v1\";\n\nClassifier\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\tB\x7f\n\x1fyandex.cloud.api.speechsense.v1B\x0f\x43lassifierProtoZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1;speechsenseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.speechsense.v1.classifier_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037yandex.cloud.api.speechsense.v1B\017ClassifierProtoZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1;speechsense'
  _globals['_CLASSIFIER']._serialized_start=77
  _globals['_CLASSIFIER']._serialized_end=136
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/assistants/v1/searchindex/search_index.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.ai.common import common_pb2 as yandex_dot_cloud_dot_ai_dot_common_dot_common__pb2
from yandex.cloud.ai.assistants.v1.searchindex import common_pb2 as yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_searchindex_dot_common__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<yandex/cloud/ai/assistants/v1/searchindex/search_index.proto\x12)yandex.cloud.ai.assistants.v1.searchindex\x1a#yandex/cloud/ai/common/common.proto\x1a\x36yandex/cloud/ai/assistants/v1/searchindex/common.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xef\x05\n\x0bSearchIndex\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x12\n\ncreated_by\x18\x05 \x01(\t\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\x07 \x01(\t\x12.\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x43\n\x11\x65xpiration_config\x18\t \x01(\x0b\x32(.yandex.cloud.ai.common.ExpirationConfig\x12.\n\nexpires_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12R\n\x06labels\x18\x0b \x03(\x0b\x32\x42.yandex.cloud.ai.assistants.v1.searchindex.SearchIndex.LabelsEntry\x12W\n\x11text_search_index\x18\x0c \x01(\x0b\x32:.yandex.cloud.ai.assistants.v1.searchindex.TextSearchIndexH\x00\x12[\n\x13vector_search_index\x18\r \x01(\x0b\x32<.yandex.cloud.ai.assistants.v1.searchindex.VectorSearchIndexH\x00\x12[\n\x13hybrid_search_index\x18\x0e \x01(\x0b\x32<.yandex.cloud.ai.assistants.v1.searchindex.HybridSearchIndexH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0b\n\tIndexType\"i\n\x0fTextSearchIndex\x12V\n\x11\x63hunking_strategy\x18\x01 \x01(\x0b\x32;.yandex.cloud.ai.assistants.v1.searchindex.ChunkingStrategy\"\xa1\x01\n\x11VectorSearchIndex\x12\x18\n\x10\x64oc_embedder_uri\x18\x01 \x01(\t\x12\x1a\n\x12query_embedder_uri\x18\x02 \x01(\t\x12V\n\x11\x63hunking_strategy\x18\x03 \x01(\x0b\x32;.yandex.cloud.ai.assistants.v1.searchindex.ChunkingStrategy\"\xdd\x03\n\x11HybridSearchIndex\x12U\n\x11text_search_index\x18\x01 \x01(\x0b\x32:.yandex.cloud.ai.assistants.v1.searchindex.TextSearchIndex\x12Y\n\x13vector_search_index\x18\x02 \x01(\x0b\x32<.yandex.cloud.ai.assistants.v1.searchindex.VectorSearchIndex\x12V\n\x11\x63hunking_strategy\x18\x03 \x01(\x0b\x32;.yandex.cloud.ai.assistants.v1.searchindex.ChunkingStrategy\x12`\n\x16normalization_strategy\x18\x04 \x01(\x0e\x32@.yandex.cloud.ai.assistants.v1.searchindex.NormalizationStrategy\x12\\\n\x14\x63ombination_strategy\x18\x05 \x01(\x0b\x32>.yandex.cloud.ai.assistants.v1.searchindex.CombinationStrategyB\x8a\x01\n-yandex.cloud.api.ai.assistants.v1.searchindexZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/searchindex;searchindexb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.assistants.v1.searchindex.search_index_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-yandex.cloud.api.ai.assistants.v1.searchindexZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/searchindex;searchindex'
  _SEARCHINDEX_LABELSENTRY._options = None
  _SEARCHINDEX_LABELSENTRY._serialized_options = b'8\001'
  _globals['_SEARCHINDEX']._serialized_start=234
  _globals['_SEARCHINDEX']._serialized_end=985
  _globals['_SEARCHINDEX_LABELSENTRY']._serialized_start=927
  _globals['_SEARCHINDEX_LABELSENTRY']._serialized_end=972
  _globals['_TEXTSEARCHINDEX']._serialized_start=987
  _globals['_TEXTSEARCHINDEX']._serialized_end=1092
  _globals['_VECTORSEARCHINDEX']._serialized_start=1095
  _globals['_VECTORSEARCHINDEX']._serialized_end=1256
  _globals['_HYBRIDSEARCHINDEX']._serialized_start=1259
  _globals['_HYBRIDSEARCHINDEX']._serialized_end=1736
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Predicate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AND_PREDICATE_FIELD_NUMBER: builtins.int
    FIELD_VALUE_PREDICATE_FIELD_NUMBER: builtins.int
    @property
    def and_predicate(self) -> global___AndPredicate: ...
    @property
    def field_value_predicate(self) -> global___FieldValuePredicate: ...
    def __init__(
        self,
        *,
        and_predicate: global___AndPredicate | None = ...,
        field_value_predicate: global___FieldValuePredicate | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["and_predicate", b"and_predicate", "field_value_predicate", b"field_value_predicate", "predicate", b"predicate"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["and_predicate", b"and_predicate", "field_value_predicate", b"field_value_predicate", "predicate", b"predicate"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["predicate", b"predicate"]) -> typing.Literal["and_predicate", "field_value_predicate"] | None: ...

global___Predicate = Predicate

@typing.final
class AndPredicate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PREDICATE_FIELD_NUMBER: builtins.int
    @property
    def predicate(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Predicate]: ...
    def __init__(
        self,
        *,
        predicate: collections.abc.Iterable[global___Predicate] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["predicate", b"predicate"]) -> None: ...

global___AndPredicate = AndPredicate

@typing.final
class FieldValuePredicate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_PATH_FIELD_NUMBER: builtins.int
    EXACT_FIELD_NUMBER: builtins.int
    PREFIX_FIELD_NUMBER: builtins.int
    SUFFIX_FIELD_NUMBER: builtins.int
    field_path: builtins.str
    exact: builtins.str
    """string representation of the value matches exactly to the given string"""
    prefix: builtins.str
    """value has given prefix"""
    suffix: builtins.str
    """value has given suffix"""
    def __init__(
        self,
        *,
        field_path: builtins.str = ...,
        exact: builtins.str = ...,
        prefix: builtins.str = ...,
        suffix: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["exact", b"exact", "prefix", b"prefix", "suffix", b"suffix", "value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["exact", b"exact", "field_path", b"field_path", "prefix", b"prefix", "suffix", b"suffix", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["value", b"value"]) -> typing.Literal["exact", "prefix", "suffix"] | None: ...

global___FieldValuePredicate = FieldValuePredicate



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.serverless.apigateway.v1 import apigateway_pb2 as yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__pb2
from yandex.cloud.serverless.apigateway.v1 import apigateway_service_pb2 as yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2


class ApiGatewayServiceStub(object):
    """A set of methods for managing API gateways.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.serverless.apigateway.v1.ApiGatewayService/Get',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.GetApiGatewayRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__pb2.ApiGateway.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.serverless.apigateway.v1.ApiGatewayService/List',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.ListApiGatewayRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.ListApiGatewayResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/yandex.cloud.serverless.apigateway.v1.ApiGatewayService/Create',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.CreateApiGatewayRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/yandex.cloud.serverless.apigateway.v1.ApiGatewayService/Update',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.UpdateApiGatewayRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/yandex.cloud.serverless.apigateway.v1.ApiGatewayService/Delete',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.DeleteApiGatewayRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.AddDomain = channel.unary_unary(
                '/yandex.cloud.serverless.apigateway.v1.ApiGatewayService/AddDomain',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.AddDomainRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.RemoveDomain = channel.unary_unary(
                '/yandex.cloud.serverless.apigateway.v1.ApiGatewayService/RemoveDomain',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.RemoveDomainRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.GetOpenapiSpec = channel.unary_unary(
                '/yandex.cloud.serverless.apigateway.v1.ApiGatewayService/GetOpenapiSpec',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.GetOpenapiSpecRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.GetOpenapiSpecResponse.FromString,
                )
        self.ListOperations = channel.unary_unary(
                '/yandex.cloud.serverless.apigateway.v1.ApiGatewayService/ListOperations',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.ListOperationsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.ListOperationsResponse.FromString,
                )
        self.ListAccessBindings = channel.unary_unary(
                '/yandex.cloud.serverless.apigateway.v1.ApiGatewayService/ListAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
                )
        self.SetAccessBindings = channel.unary_unary(
                '/yandex.cloud.serverless.apigateway.v1.ApiGatewayService/SetAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.UpdateAccessBindings = channel.unary_unary(
                '/yandex.cloud.serverless.apigateway.v1.ApiGatewayService/UpdateAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )


class ApiGatewayServiceServicer(object):
    """A set of methods for managing API gateways.
    """

    def Get(self, request, context):
        """Returns the specified API gateway. Note that only API gateway basic attributes are returned.
        To get associated openapi specification, make a [GetOpenapiSpec](#GetOpenapiSpec) request.

        To get the list of all available API gateways, make a [List] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves the list of API gateways in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates an API gateway in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates the specified API gateway.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes the specified API gateway.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddDomain(self, request, context):
        """Attaches domain to the specified API gateway.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveDomain(self, request, context):
        """Detaches domain from the specified API gateway.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOpenapiSpec(self, request, context):
        """Returns the OpenAPI specification of specified API gateway.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOperations(self, request, context):
        """Lists operations for the specified API gateway.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAccessBindings(self, request, context):
        """Lists existing access bindings for the specified API gateway.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAccessBindings(self, request, context):
        """Sets access bindings for the specified API gateway.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAccessBindings(self, request, context):
        """Updates access bindings for the specified API gateway.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ApiGatewayServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.GetApiGatewayRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__pb2.ApiGateway.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.ListApiGatewayRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.ListApiGatewayResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.CreateApiGatewayRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.UpdateApiGatewayRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.DeleteApiGatewayRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'AddDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.AddDomain,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.AddDomainRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'RemoveDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveDomain,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.RemoveDomainRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'GetOpenapiSpec': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOpenapiSpec,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.GetOpenapiSpecRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.GetOpenapiSpecResponse.SerializeToString,
            ),
            'ListOperations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOperations,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.ListOperationsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.ListOperationsResponse.SerializeToString,
            ),
            'ListAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.SerializeToString,
            ),
            'SetAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdateAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.serverless.apigateway.v1.ApiGatewayService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ApiGatewayService(object):
    """A set of methods for managing API gateways.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.apigateway.v1.ApiGatewayService/Get',
            yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.GetApiGatewayRequest.SerializeToString,
            yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__pb2.ApiGateway.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.apigateway.v1.ApiGatewayService/List',
            yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.ListApiGatewayRequest.SerializeToString,
            yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.ListApiGatewayResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.apigateway.v1.ApiGatewayService/Create',
            yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.CreateApiGatewayRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.apigateway.v1.ApiGatewayService/Update',
            yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.UpdateApiGatewayRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.apigateway.v1.ApiGatewayService/Delete',
            yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.DeleteApiGatewayRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.apigateway.v1.ApiGatewayService/AddDomain',
            yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.AddDomainRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.apigateway.v1.ApiGatewayService/RemoveDomain',
            yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.RemoveDomainRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOpenapiSpec(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.apigateway.v1.ApiGatewayService/GetOpenapiSpec',
            yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.GetOpenapiSpecRequest.SerializeToString,
            yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.GetOpenapiSpecResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOperations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.apigateway.v1.ApiGatewayService/ListOperations',
            yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.ListOperationsRequest.SerializeToString,
            yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__service__pb2.ListOperationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.apigateway.v1.ApiGatewayService/ListAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.apigateway.v1.ApiGatewayService/SetAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.apigateway.v1.ApiGatewayService/UpdateAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.mdb.greenplum.v1.hba_rule_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CreateHBARuleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    HBA_RULE_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Greenplum cluster.
    To get the Greenplum cluster ID use a [ClusterService.List] request.
    """
    @property
    def hba_rule(self) -> yandex.cloud.mdb.greenplum.v1.hba_rule_pb2.HBARule:
        """New hba rule for the cluster."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        hba_rule: yandex.cloud.mdb.greenplum.v1.hba_rule_pb2.HBARule | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["hba_rule", b"hba_rule"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "hba_rule", b"hba_rule"]) -> None: ...

global___CreateHBARuleRequest = CreateHBARuleRequest

@typing.final
class UpdateHBARuleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    HBA_RULE_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Greenplum cluster.
    To get the Greenplum cluster ID use a [ClusterService.List] request.
    """
    @property
    def hba_rule(self) -> yandex.cloud.mdb.greenplum.v1.hba_rule_pb2.HBARule:
        """Updated hba rule for the cluster."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        hba_rule: yandex.cloud.mdb.greenplum.v1.hba_rule_pb2.HBARule | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["hba_rule", b"hba_rule"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "hba_rule", b"hba_rule"]) -> None: ...

global___UpdateHBARuleRequest = UpdateHBARuleRequest

@typing.final
class DeleteHBARuleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Greenplum cluster.
    To get the Greenplum cluster ID use a [ClusterService.List] request.
    """
    priority: builtins.int
    """Priority of the Greenplum cluster rule."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        priority: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "priority", b"priority"]) -> None: ...

global___DeleteHBARuleRequest = DeleteHBARuleRequest

@typing.final
class ListHBARulesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Greenplum cluster.
    To get the Greenplum cluster ID use a [ClusterService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___ListHBARulesRequest = ListHBARulesRequest

@typing.final
class ListHBARulesAtRevisionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    REVISION_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Greenplum cluster.
    To get the Greenplum cluster ID use a [ClusterService.List] request.
    """
    revision: builtins.int
    """Cluster revision"""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        revision: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "revision", b"revision"]) -> None: ...

global___ListHBARulesAtRevisionRequest = ListHBARulesAtRevisionRequest

@typing.final
class ListHBARulesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HBA_RULES_FIELD_NUMBER: builtins.int
    @property
    def hba_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.greenplum.v1.hba_rule_pb2.HBARule]:
        """Requested list of hba rules for the cluster."""

    def __init__(
        self,
        *,
        hba_rules: collections.abc.Iterable[yandex.cloud.mdb.greenplum.v1.hba_rule_pb2.HBARule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["hba_rules", b"hba_rules"]) -> None: ...

global___ListHBARulesResponse = ListHBARulesResponse

@typing.final
class BatchUpdateHBARulesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    HBA_RULES_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Greenplum cluster.
    To get the Greenplum cluster ID use a [ClusterService.List] request.
    """
    @property
    def hba_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.greenplum.v1.hba_rule_pb2.HBARule]:
        """List of new hba rules for the cluster."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        hba_rules: collections.abc.Iterable[yandex.cloud.mdb.greenplum.v1.hba_rule_pb2.HBARule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "hba_rules", b"hba_rules"]) -> None: ...

global___BatchUpdateHBARulesRequest = BatchUpdateHBARulesRequest

@typing.final
class HBARulesMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Greenplum cluster which HBA rules was affected."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___HBARulesMetadata = HBARulesMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.mdb.kafka.v1.topic_pb2
import yandex.cloud.mdb.kafka.v1.topic_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class TopicServiceStub:
    """A set of methods for managing Kafka topics."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.kafka.v1.topic_service_pb2.GetTopicRequest,
        yandex.cloud.mdb.kafka.v1.topic_pb2.Topic,
    ]
    """Returns the specified Kafka topic.

    To get the list of available Kafka topics, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.kafka.v1.topic_service_pb2.ListTopicsRequest,
        yandex.cloud.mdb.kafka.v1.topic_service_pb2.ListTopicsResponse,
    ]
    """Retrieves the list of Kafka topics in the specified cluster."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.kafka.v1.topic_service_pb2.CreateTopicRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a new Kafka topic in the specified cluster."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.kafka.v1.topic_service_pb2.UpdateTopicRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified Kafka topic."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.kafka.v1.topic_service_pb2.DeleteTopicRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified Kafka topic."""

class TopicServiceAsyncStub:
    """A set of methods for managing Kafka topics."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.kafka.v1.topic_service_pb2.GetTopicRequest,
        yandex.cloud.mdb.kafka.v1.topic_pb2.Topic,
    ]
    """Returns the specified Kafka topic.

    To get the list of available Kafka topics, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.kafka.v1.topic_service_pb2.ListTopicsRequest,
        yandex.cloud.mdb.kafka.v1.topic_service_pb2.ListTopicsResponse,
    ]
    """Retrieves the list of Kafka topics in the specified cluster."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.kafka.v1.topic_service_pb2.CreateTopicRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a new Kafka topic in the specified cluster."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.kafka.v1.topic_service_pb2.UpdateTopicRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified Kafka topic."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.kafka.v1.topic_service_pb2.DeleteTopicRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified Kafka topic."""

class TopicServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Kafka topics."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.mdb.kafka.v1.topic_service_pb2.GetTopicRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.kafka.v1.topic_pb2.Topic, collections.abc.Awaitable[yandex.cloud.mdb.kafka.v1.topic_pb2.Topic]]:
        """Returns the specified Kafka topic.

        To get the list of available Kafka topics, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.mdb.kafka.v1.topic_service_pb2.ListTopicsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.kafka.v1.topic_service_pb2.ListTopicsResponse, collections.abc.Awaitable[yandex.cloud.mdb.kafka.v1.topic_service_pb2.ListTopicsResponse]]:
        """Retrieves the list of Kafka topics in the specified cluster."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.mdb.kafka.v1.topic_service_pb2.CreateTopicRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a new Kafka topic in the specified cluster."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.mdb.kafka.v1.topic_service_pb2.UpdateTopicRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified Kafka topic."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.mdb.kafka.v1.topic_service_pb2.DeleteTopicRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified Kafka topic."""

def add_TopicServiceServicer_to_server(servicer: TopicServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.datasphere.v2 import project_pb2 as yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__pb2
from yandex.cloud.datasphere.v2 import project_service_pb2 as yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2
from yandex.cloud.datasphere.v2 import restrictions_pb2 as yandex_dot_cloud_dot_datasphere_dot_v2_dot_restrictions__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class ProjectServiceStub(object):
    """A set of methods for managing Project resources.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.ProjectService/Create',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.CreateProjectRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.ProjectService/Update',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.UpdateProjectRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.ProjectService/Delete',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.DeleteProjectRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Open = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.ProjectService/Open',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.OpenProjectRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Get = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.ProjectService/Get',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.GetProjectRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__pb2.Project.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.ProjectService/List',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.ListProjectsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.ListProjectsResponse.FromString,
                )
        self.GetUnitBalance = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.ProjectService/GetUnitBalance',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.GetUnitBalanceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.GetUnitBalanceResponse.FromString,
                )
        self.SetUnitBalance = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.ProjectService/SetUnitBalance',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.SetUnitBalanceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Execute = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.ProjectService/Execute',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.ProjectExecutionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListAccessBindings = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.ProjectService/ListAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
                )
        self.SetAccessBindings = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.ProjectService/SetAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.UpdateAccessBindings = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.ProjectService/UpdateAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.AddResource = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.ProjectService/AddResource',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.AddResourceToProjectRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.RemoveResource = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.ProjectService/RemoveResource',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.RemoveResourceFromProjectRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ResizeDisk = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.ProjectService/ResizeDisk',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.ResizeProjectDiskRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.GetRestrictionsMeta = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.ProjectService/GetRestrictionsMeta',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_restrictions__pb2.GetRestrictionsMetaResponse.FromString,
                )
        self.GetRestrictions = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.ProjectService/GetRestrictions',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.GetProjectRestrictionsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_restrictions__pb2.RestrictionsResponse.FromString,
                )
        self.SetRestrictions = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.ProjectService/SetRestrictions',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.SetProjectRestrictionsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )


class ProjectServiceServicer(object):
    """A set of methods for managing Project resources.
    """

    def Create(self, request, context):
        """Creates a project in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates the specified project.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes the specified project.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Open(self, request, context):
        """Opens the specified project.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Returns the specified project.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Lists projects for the specified community.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUnitBalance(self, request, context):
        """Returns the unit balance of the specified project.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetUnitBalance(self, request, context):
        """Sets the unit balance of the specified project.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Execute(self, request, context):
        """Executes code of the specified notebook using configuration defined in the project settings. If the default project configuration is not specified, `c1.4` is used.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAccessBindings(self, request, context):
        """Lists access bindings for the project.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAccessBindings(self, request, context):
        """Sets access bindings for the project.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAccessBindings(self, request, context):
        """Updates access bindings for the project.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddResource(self, request, context):
        """Adds shared resource to project
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveResource(self, request, context):
        """Removes shared resource from project
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResizeDisk(self, request, context):
        """Resizes project disk
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRestrictionsMeta(self, request, context):
        """Get meta information about available restrictions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRestrictions(self, request, context):
        """Get current project restrictions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetRestrictions(self, request, context):
        """Set project restrictions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProjectServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.CreateProjectRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.UpdateProjectRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.DeleteProjectRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Open': grpc.unary_unary_rpc_method_handler(
                    servicer.Open,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.OpenProjectRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.GetProjectRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__pb2.Project.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.ListProjectsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.ListProjectsResponse.SerializeToString,
            ),
            'GetUnitBalance': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUnitBalance,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.GetUnitBalanceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.GetUnitBalanceResponse.SerializeToString,
            ),
            'SetUnitBalance': grpc.unary_unary_rpc_method_handler(
                    servicer.SetUnitBalance,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.SetUnitBalanceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Execute': grpc.unary_unary_rpc_method_handler(
                    servicer.Execute,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.ProjectExecutionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.SerializeToString,
            ),
            'SetAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdateAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'AddResource': grpc.unary_unary_rpc_method_handler(
                    servicer.AddResource,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.AddResourceToProjectRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'RemoveResource': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveResource,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.RemoveResourceFromProjectRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ResizeDisk': grpc.unary_unary_rpc_method_handler(
                    servicer.ResizeDisk,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.ResizeProjectDiskRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'GetRestrictionsMeta': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRestrictionsMeta,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_restrictions__pb2.GetRestrictionsMetaResponse.SerializeToString,
            ),
            'GetRestrictions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRestrictions,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.GetProjectRestrictionsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_restrictions__pb2.RestrictionsResponse.SerializeToString,
            ),
            'SetRestrictions': grpc.unary_unary_rpc_method_handler(
                    servicer.SetRestrictions,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.SetProjectRestrictionsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.datasphere.v2.ProjectService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ProjectService(object):
    """A set of methods for managing Project resources.
    """

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.ProjectService/Create',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.CreateProjectRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.ProjectService/Update',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.UpdateProjectRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.ProjectService/Delete',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.DeleteProjectRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Open(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.ProjectService/Open',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.OpenProjectRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.ProjectService/Get',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.GetProjectRequest.SerializeToString,
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__pb2.Project.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.ProjectService/List',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.ListProjectsRequest.SerializeToString,
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.ListProjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUnitBalance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.ProjectService/GetUnitBalance',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.GetUnitBalanceRequest.SerializeToString,
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.GetUnitBalanceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetUnitBalance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.ProjectService/SetUnitBalance',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.SetUnitBalanceRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Execute(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.ProjectService/Execute',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.ProjectExecutionRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.ProjectService/ListAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.ProjectService/SetAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.ProjectService/UpdateAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddResource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.ProjectService/AddResource',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.AddResourceToProjectRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveResource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.ProjectService/RemoveResource',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.RemoveResourceFromProjectRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResizeDisk(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.ProjectService/ResizeDisk',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.ResizeProjectDiskRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRestrictionsMeta(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.ProjectService/GetRestrictionsMeta',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_restrictions__pb2.GetRestrictionsMetaResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRestrictions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.ProjectService/GetRestrictions',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.GetProjectRestrictionsRequest.SerializeToString,
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_restrictions__pb2.RestrictionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetRestrictions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.ProjectService/SetRestrictions',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__service__pb2.SetProjectRestrictionsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.ai.foundation_models.v1.image_generation import image_generation_service_pb2 as yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_image__generation_dot_image__generation__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class ImageGenerationAsyncServiceStub(object):
    """Service for creating images based on a text description. 
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Generate = channel.unary_unary(
                '/yandex.cloud.ai.foundation_models.v1.image_generation.ImageGenerationAsyncService/Generate',
                request_serializer=yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_image__generation_dot_image__generation__service__pb2.ImageGenerationRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )


class ImageGenerationAsyncServiceServicer(object):
    """Service for creating images based on a text description. 
    """

    def Generate(self, request, context):
        """A method for generating an image based on a textual description.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ImageGenerationAsyncServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Generate': grpc.unary_unary_rpc_method_handler(
                    servicer.Generate,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_image__generation_dot_image__generation__service__pb2.ImageGenerationRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.ai.foundation_models.v1.image_generation.ImageGenerationAsyncService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ImageGenerationAsyncService(object):
    """Service for creating images based on a text description. 
    """

    @staticmethod
    def Generate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.ai.foundation_models.v1.image_generation.ImageGenerationAsyncService/Generate',
            yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_image__generation_dot_image__generation__service__pb2.ImageGenerationRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
